'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = createMakeTheme;
exports.makeScopedTheme = makeScopedTheme;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Convert a theme into a makeTheme
 * @param theme
 */
var toMakeTheme = exports.toMakeTheme = function toMakeTheme(theme) {
  return function (userTheme) {
    return _extends({}, theme, userTheme);
  };
};

/**
 * Convert a scoped theme into a makeTheme
 * @param theme
 */
var toMakeScopedTheme = exports.toMakeScopedTheme = function toMakeScopedTheme(theme) {
  return function (userTheme) {
    var result = {};
    Object.keys(theme).forEach(function (key) {
      return result = _defineProperty({}, key, _extends({}, theme[key], userTheme));
    }); // eslint-disable-line no-return-assign
    return result;
  };
};

function makeThemeFromList(list, theme) {
  var all = [].concat(list);
  var t = theme;
  var mt = void 0;
  while (mt = all.pop()) {
    // eslint-disable-line
    t = mt(t);
  }
  return t;
}

/**
 * Create a makeTheme using a list of makeTheme
 * @param list
 * @returns {function(*=): *}
 */
function createMakeTheme(list) {
  return function (theme) {
    return makeThemeFromList(list, theme);
  };
}

/**
* Create a scoped makeTheme
* @param userTheme
* @param scopeName string
*
**/

function makeScopedTheme() {
  var userTheme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _defineProperty({}, scopeName, {});
  var scopeName = arguments[1];

  if (scopeName === undefined) return console.warn('You may have forgotten to set the scope name in the makeScopedTheme function.');

  var newTheme = _defineProperty({}, scopeName, {});
  var v = newTheme[scopeName];
  var u = userTheme[scopeName] || {};

  Object.keys(userTheme).forEach(function (variable) {
    v[variable] = u[variable] || userTheme[variable];
  });

  return _defineProperty({}, scopeName, _extends({}, userTheme, v));
}